==> jclouds-2.4.0-source-release.tar.gz: jclouds-2.4.0/apis/sqs/src/main/java/org/jclouds/sqs/xml/internal/BaseRegexQueueHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.sqs.xml.internal;

import java.net.URI;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.inject.Singleton;

import com.google.common.base.Strings;
import com.google.common.collect.FluentIterable;
import com.google.common.collect.ImmutableSet;
import com.google.common.collect.ImmutableSet.Builder;

/**
 * 
 * @see <a href=
 *      "http://docs.amazonwebservices.com/AWSSimpleQueueService/latest/APIReference/Query_QueryListQueues.html"
 *      />
 */
@Singleton
public class BaseRegexQueueHandler {
   protected final Pattern pattern = Pattern.compile("<QueueUrl>(https?://[\\S&&[^<]]+)</QueueUrl>");

   public FluentIterable<URI> parse(String in) {
      Builder<URI> queues = ImmutableSet.<URI> builder();
      Matcher matcher = pattern.matcher(in);
      while (matcher.find()) {
         String uriText = matcher.group(1);
         if (!Strings.isNullOrEmpty(uriText))
            queues.add(URI.create(uriText));
      }
      return FluentIterable.from(queues.build());
   }

}

==> jclouds-2.7.0-source-release.tar.gz: jclouds-2.7.0/apis/sqs/src/main/java/org/jclouds/sqs/xml/internal/BaseRegexQueueHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.sqs.xml.internal;

import java.net.URI;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import jakarta.inject.Singleton;

import com.google.common.base.Strings;
import com.google.common.collect.FluentIterable;
import com.google.common.collect.ImmutableSet;
import com.google.common.collect.ImmutableSet.Builder;

/**
 * 
 * @see <a href=
 *      "http://docs.amazonwebservices.com/AWSSimpleQueueService/latest/APIReference/Query_QueryListQueues.html"
 *      />
 */
@Singleton
public class BaseRegexQueueHandler {
   protected final Pattern pattern = Pattern.compile("<QueueUrl>(https?://[\\S&&[^<]]+)</QueueUrl>");

   public FluentIterable<URI> parse(String in) {
      Builder<URI> queues = ImmutableSet.<URI> builder();
      Matcher matcher = pattern.matcher(in);
      while (matcher.find()) {
         String uriText = matcher.group(1);
         if (!Strings.isNullOrEmpty(uriText))
            queues.add(URI.create(uriText));
      }
      return FluentIterable.from(queues.build());
   }

}
